# Masked Deep Autoregressive models for Density Estimation
Generic implementation of Masked Deep Autoregressive models for Density Estimation in [PyTorch](https://pytorch.org/) and [PytorchLightning](https://www.pytorchlightning.ai/). 

## Installation
In order to network implementations install `mdade` via pip:
```shell
pip install mdade
```
In case you wish to employ the training procedures and datamodule implementations (on top of `pytorch-lightning`), you would need to install the additional tools as well:

```shell
pip install "mdade[tools]"
```
